@@ -10,8 +10,8 @@ our @EXPORT_OK = qw(
                        is_env_res
                );
 
-our $VERSION = '0.02'; # VERSION
-our $DATE = '2014-08-16'; # DATE
+our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-09-03'; # DATE
 
 sub is_env_res {
     my $res = shift;
@@ -50,7 +50,7 @@ Perinci::Result::Util - Utilities related to enveloped result
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::Result::Util (from Perl distribution Perinci-Result-Util), released on 2014-08-16.
+This document describes version 0.03 of Perinci::Result::Util (from Perl distribution Perinci-Result-Util), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Re
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Result-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Result-Util>.
 
 =head1 BUGS
 
@@ -88,11 +88,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
